@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,8 +27,8 @@ class GwlbClient(AbstractClient):
 
 
     def AssociateTargetGroups(self, request):
-        """本接口(AssociateTargetGroups)用来将目标组绑定到负载均衡。
-        本接口为异步接口，本接口返回成功后需以返回的 RequestID 为入参，调用 DescribeTaskStatus 接口查询本次任务是否成功。
+        r"""本接口(AssociateTargetGroups)用来将目标组绑定到负载均衡。
+        本接口为异步接口，本接口返回成功后需以返回的 RequestID 为入参，调用 [DescribeTaskStatus](https://cloud.tencent.com/document/product/214/30683) 接口查询本次任务是否成功。
 
         :param request: Request instance for AssociateTargetGroups.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.AssociateTargetGroupsRequest`
@@ -51,9 +51,9 @@ class GwlbClient(AbstractClient):
 
 
     def CreateGatewayLoadBalancer(self, request):
-        """本接口(CreateGatewayLoadBalancer)用来创建网关负载均衡实例。为了使用网关负载均衡服务，您必须购买一个或多个网关负载均衡实例。成功调用该接口后，会返回网关负载均衡实例的唯一 ID。
+        r"""本接口(CreateGatewayLoadBalancer)用来创建网关负载均衡实例。为了使用网关负载均衡服务，您必须购买一个或多个网关负载均衡实例。成功调用该接口后，会返回网关负载均衡实例的唯一 ID。
         注意：单个账号在每个地域的默认购买配额为：10个。
-        本接口为异步接口，接口成功返回后，可使用 DescribeGatewayLoadBalancers 接口查询负载均衡实例的状态（如创建中、正常），以确定是否创建成功。
+        本接口为异步接口，接口成功返回后，可使用 [DescribeTaskStatus](https://cloud.tencent.com/document/api/1782/111700) 接口查询负载均衡实例的状态。
 
         :param request: Request instance for CreateGatewayLoadBalancer.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.CreateGatewayLoadBalancerRequest`
@@ -76,7 +76,7 @@ class GwlbClient(AbstractClient):
 
 
     def CreateTargetGroup(self, request):
-        """创建目标组。该功能正在内测中，如需使用，请通过[工单申请](https://console.cloud.tencent.com/workorder/category?level1_id=6&level2_id=163&source=0&data_title=%E8%B4%9F%E8%BD%BD%E5%9D%87%E8%A1%A1%20LB&step=1)。
+        r"""创建目标组。
 
         :param request: Request instance for CreateTargetGroup.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.CreateTargetGroupRequest`
@@ -99,8 +99,8 @@ class GwlbClient(AbstractClient):
 
 
     def DeleteGatewayLoadBalancer(self, request):
-        """DeleteGatewayLoadBalancer 接口用以删除指定的一个或多个网关负载均衡实例。成功删除后，会把网关负载均衡实例与后端服务解绑。
-        本接口为异步接口，接口返回成功后，需以返回的 RequestId 为入参，调用 DescribeTaskStatus 接口查询本次任务是否成功。
+        r"""DeleteGatewayLoadBalancer 接口用以删除指定的一个或多个网关负载均衡实例。成功删除后，会把网关负载均衡实例与后端服务解绑。
+        本接口为异步接口，接口返回成功后，需以返回的 RequestId 为入参，调用 [DescribeTaskStatus](https://cloud.tencent.com/document/api/1782/111700) 接口查询本次任务是否成功。
 
         :param request: Request instance for DeleteGatewayLoadBalancer.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DeleteGatewayLoadBalancerRequest`
@@ -123,7 +123,7 @@ class GwlbClient(AbstractClient):
 
 
     def DeleteTargetGroups(self, request):
-        """删除目标组
+        r"""删除目标组
 
         :param request: Request instance for DeleteTargetGroups.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DeleteTargetGroupsRequest`
@@ -146,8 +146,7 @@ class GwlbClient(AbstractClient):
 
 
     def DeregisterTargetGroupInstances(self, request):
-        """从目标组中解绑服务器。
-        本接口为异步接口，本接口返回成功后需以返回的 RequestID 为入参，调用 DescribeTaskStatus 接口查询本次任务是否成功。
+        r"""从目标组中解绑服务器。
 
         :param request: Request instance for DeregisterTargetGroupInstances.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DeregisterTargetGroupInstancesRequest`
@@ -170,7 +169,7 @@ class GwlbClient(AbstractClient):
 
 
     def DescribeGatewayLoadBalancers(self, request):
-        """查询一个地域的网关负载均衡实例列表。
+        r"""查询一个地域的网关负载均衡实例列表。
 
         :param request: Request instance for DescribeGatewayLoadBalancers.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DescribeGatewayLoadBalancersRequest`
@@ -193,7 +192,7 @@ class GwlbClient(AbstractClient):
 
 
     def DescribeTargetGroupInstanceStatus(self, request):
-        """查询目标组后端服务状态。目前仅支持网关负载均衡类型的目标组支持查询后端服务状态。
+        r"""查询目标组后端服务状态。目前仅支持网关负载均衡类型的目标组支持查询后端服务状态。
 
         :param request: Request instance for DescribeTargetGroupInstanceStatus.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DescribeTargetGroupInstanceStatusRequest`
@@ -216,7 +215,7 @@ class GwlbClient(AbstractClient):
 
 
     def DescribeTargetGroupInstances(self, request):
-        """获取目标组绑定的服务器信息。
+        r"""获取目标组绑定的服务器信息。
 
         :param request: Request instance for DescribeTargetGroupInstances.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DescribeTargetGroupInstancesRequest`
@@ -239,7 +238,7 @@ class GwlbClient(AbstractClient):
 
 
     def DescribeTargetGroupList(self, request):
-        """获取目标组列表
+        r"""获取目标组列表
 
         :param request: Request instance for DescribeTargetGroupList.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DescribeTargetGroupListRequest`
@@ -262,7 +261,7 @@ class GwlbClient(AbstractClient):
 
 
     def DescribeTargetGroups(self, request):
-        """查询目标组信息
+        r"""查询目标组信息
 
         :param request: Request instance for DescribeTargetGroups.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DescribeTargetGroupsRequest`
@@ -285,7 +284,7 @@ class GwlbClient(AbstractClient):
 
 
     def DescribeTaskStatus(self, request):
-        """本接口用于查询异步任务的执行状态，对于非查询类的接口（创建/删除负载均衡实例等），在接口调用成功后，都需要使用本接口查询任务最终是否执行成功。
+        r"""本接口用于查询异步任务的执行状态，对于非查询类的接口（创建/删除负载均衡实例等），在接口调用成功后，都需要使用本接口查询任务最终是否执行成功。
 
         :param request: Request instance for DescribeTaskStatus.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DescribeTaskStatusRequest`
@@ -308,8 +307,8 @@ class GwlbClient(AbstractClient):
 
 
     def DisassociateTargetGroups(self, request):
-        """解除负载均衡和目标组的关联关系。
-        本接口为异步接口，本接口返回成功后需以返回的 RequestID 为入参，调用 DescribeTaskStatus 接口查询本次任务是否成功。
+        r"""解除负载均衡和目标组的关联关系。
+        本接口为异步接口，本接口返回成功后需以返回的 RequestID 为入参，调用 [DescribeTaskStatus](https://cloud.tencent.com/document/product/214/30683) 接口查询本次任务是否成功。
 
         :param request: Request instance for DisassociateTargetGroups.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.DisassociateTargetGroupsRequest`
@@ -332,7 +331,7 @@ class GwlbClient(AbstractClient):
 
 
     def InquirePriceCreateGatewayLoadBalancer(self, request):
-        """InquirePriceCreateGatewayLoadBalancer接口查询创建网关负载均衡的价格。
+        r"""InquirePriceCreateGatewayLoadBalancer接口查询创建网关负载均衡的价格。
 
         :param request: Request instance for InquirePriceCreateGatewayLoadBalancer.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.InquirePriceCreateGatewayLoadBalancerRequest`
@@ -355,7 +354,7 @@ class GwlbClient(AbstractClient):
 
 
     def ModifyGatewayLoadBalancerAttribute(self, request):
-        """ModifyGatewayLoadBalancerAttribute 接口用于修改负载均衡实例的属性。支持修改负载均衡实例的名称、带宽上限。
+        r"""ModifyGatewayLoadBalancerAttribute 接口用于修改负载均衡实例的属性。支持修改负载均衡实例的名称、带宽上限。
 
         :param request: Request instance for ModifyGatewayLoadBalancerAttribute.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.ModifyGatewayLoadBalancerAttributeRequest`
@@ -378,7 +377,7 @@ class GwlbClient(AbstractClient):
 
 
     def ModifyTargetGroupAttribute(self, request):
-        """修改目标组的名称、健康探测等属性。
+        r"""修改目标组的名称、健康探测等属性。
 
         :param request: Request instance for ModifyTargetGroupAttribute.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.ModifyTargetGroupAttributeRequest`
@@ -401,8 +400,7 @@ class GwlbClient(AbstractClient):
 
 
     def ModifyTargetGroupInstancesWeight(self, request):
-        """修改目标组的服务器权重。
-        本接口为异步接口，本接口返回成功后需以返回的 RequestID 为入参，调用 DescribeTaskStatus 接口查询本次任务是否成功。
+        r"""修改目标组的服务器权重。
 
         :param request: Request instance for ModifyTargetGroupInstancesWeight.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.ModifyTargetGroupInstancesWeightRequest`
@@ -425,8 +423,7 @@ class GwlbClient(AbstractClient):
 
 
     def RegisterTargetGroupInstances(self, request):
-        """注册服务器到目标组。
-        本接口为异步接口，本接口返回成功后需以返回的 RequestID 为入参，调用 DescribeTaskStatus 接口查询本次任务是否成功。
+        r"""注册服务器到目标组。
 
         :param request: Request instance for RegisterTargetGroupInstances.
         :type request: :class:`tencentcloud.gwlb.v20240906.models.RegisterTargetGroupInstancesRequest`
