@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -146,6 +146,9 @@ INVALIDPARAMETERVALUE_AUDIOCODEC = 'InvalidParameterValue.AudioCodec'
 # 参数错误：音频流采样率。
 INVALIDPARAMETERVALUE_AUDIOSAMPLERATE = 'InvalidParameterValue.AudioSampleRate'
 
+# 擦除模板自动区域错误
+INVALIDPARAMETERVALUE_AUTOAREAS = 'InvalidParameterValue.AutoAreas'
+
 # 无效的音频/视频码率。
 INVALIDPARAMETERVALUE_BITRATE = 'InvalidParameterValue.Bitrate'
 
@@ -176,6 +179,9 @@ INVALIDPARAMETERVALUE_COORDINATEORIGIN = 'InvalidParameterValue.CoordinateOrigin
 # 参数值错误：智能封面控制字段参数错误。
 INVALIDPARAMETERVALUE_COVERCONFIGURE = 'InvalidParameterValue.CoverConfigure'
 
+# 擦除模板指定区域错误
+INVALIDPARAMETERVALUE_CUSTOMAREAS = 'InvalidParameterValue.CustomAreas'
+
 # 参数值错误：人脸默认库过滤标签非法。
 INVALIDPARAMETERVALUE_DEFAULTLIBRARYLABELSET = 'InvalidParameterValue.DefaultLibraryLabelSet'
 
@@ -200,6 +206,18 @@ INVALIDPARAMETERVALUE_DISABLEHIGHERVIDEORESOLUTION = 'InvalidParameterValue.Disa
 # 模板开启的检测项为空。
 INVALIDPARAMETERVALUE_EMPTYDETECTITEM = 'InvalidParameterValue.EmptyDetectItem'
 
+# 擦除模板隐私保护配置错误
+INVALIDPARAMETERVALUE_ERASEPRIVACYCONFIG = 'InvalidParameterValue.ErasePrivacyConfig'
+
+# 擦除模板字幕擦除配置错误
+INVALIDPARAMETERVALUE_ERASESUBTITLECONFIG = 'InvalidParameterValue.EraseSubtitleConfig'
+
+# 擦除模板擦除类型错误
+INVALIDPARAMETERVALUE_ERASETYPE = 'InvalidParameterValue.EraseType'
+
+# 擦除模板水印擦除配置错误
+INVALIDPARAMETERVALUE_ERASEWATERMARKCONFIG = 'InvalidParameterValue.EraseWatermarkConfig'
+
 # 参数值错误：人脸重复。
 INVALIDPARAMETERVALUE_FACEDUPLICATE = 'InvalidParameterValue.FaceDuplicate'
 
@@ -281,6 +299,12 @@ INVALIDPARAMETERVALUE_OBJECTLIBRARY = 'InvalidParameterValue.ObjectLibrary'
 # 参数值错误：人脸图片格式错误。
 INVALIDPARAMETERVALUE_PICFORMATERROR = 'InvalidParameterValue.PicFormatError'
 
+# 擦除模板隐私保护模型错误
+INVALIDPARAMETERVALUE_PRIVACYMODEL = 'InvalidParameterValue.PrivacyModel'
+
+# 擦除模板隐私保护目标错误
+INVALIDPARAMETERVALUE_PRIVACYTARGETS = 'InvalidParameterValue.PrivacyTargets'
+
 # 参数值错误：Quality。
 INVALIDPARAMETERVALUE_QUALITY = 'InvalidParameterValue.Quality'
 
@@ -332,9 +356,18 @@ INVALIDPARAMETERVALUE_SOURCELANGUAGE = 'InvalidParameterValue.SourceLanguage'
 # 源文件错误。
 INVALIDPARAMETERVALUE_SRCFILE = 'InvalidParameterValue.SrcFile'
 
+# 擦除模板字幕擦除方式错误
+INVALIDPARAMETERVALUE_SUBTITLEERASEMETHOD = 'InvalidParameterValue.SubtitleEraseMethod'
+
 # 参数值错误：SubtitleFormat 参数非法。
 INVALIDPARAMETERVALUE_SUBTITLEFORMAT = 'InvalidParameterValue.SubtitleFormat'
 
+# 擦除模板字幕擦除语种错误
+INVALIDPARAMETERVALUE_SUBTITLELANG = 'InvalidParameterValue.SubtitleLang'
+
+# 擦除模板字幕擦除模型错误
+INVALIDPARAMETERVALUE_SUBTITLEMODEL = 'InvalidParameterValue.SubtitleModel'
+
 # 参数值错误：字幕语言类型
 INVALIDPARAMETERVALUE_SUBTITLETYPE = 'InvalidParameterValue.SubtitleType'
 
@@ -365,6 +398,9 @@ INVALIDPARAMETERVALUE_TEXTALPHA = 'InvalidParameterValue.TextAlpha'
 # 参数错误：文字模板。
 INVALIDPARAMETERVALUE_TEXTTEMPLATE = 'InvalidParameterValue.TextTemplate'
 
+# 擦除模板字幕擦除翻译目标语种错误
+INVALIDPARAMETERVALUE_TRANSDSTLANG = 'InvalidParameterValue.TransDstLang'
+
 # 参数值错误：翻译目标语言
 INVALIDPARAMETERVALUE_TRANSLATEDSTLANGUAGE = 'InvalidParameterValue.TranslateDstLanguage'
 
@@ -389,6 +425,12 @@ INVALIDPARAMETERVALUE_VIDEOCODEC = 'InvalidParameterValue.VideoCodec'
 # 参数值错误：视频源语言错误
 INVALIDPARAMETERVALUE_VIDEOSRCLANGUAGE = 'InvalidParameterValue.VideoSrcLanguage'
 
+# 擦除模板去水印擦除方式错误
+INVALIDPARAMETERVALUE_WATERMARKERASEMETHOD = 'InvalidParameterValue.WatermarkEraseMethod'
+
+# 擦除模板去水印擦除模型错误
+INVALIDPARAMETERVALUE_WATERMARKMODEL = 'InvalidParameterValue.WatermarkModel'
+
 # 参数错误：宽度。
 INVALIDPARAMETERVALUE_WIDTH = 'InvalidParameterValue.Width'
 
@@ -398,6 +440,12 @@ INVALIDPARAMETERVALUE_XPOS = 'InvalidParameterValue.XPos'
 # 水印原点距离视频图像坐标原点的垂直位置。支持 %、px 两种格式。
 INVALIDPARAMETERVALUE_YPOS = 'InvalidParameterValue.YPos'
 
+# 热词库创建数量到达默认上限
+LIMITEXCEEDED_TOOMUCHHOTWORDS = 'LimitExceeded.TooMuchHotWords'
+
+# 大型热词库创建到达上限
+LIMITEXCEEDED_TOOMUCHLARGEHOTWORDS = 'LimitExceeded.TooMuchLargeHotWords'
+
 # 超过限制值：模板数超限。
 LIMITEXCEEDED_TOOMUCHTEMPLATE = 'LimitExceeded.TooMuchTemplate'
 
